@@ -42,3 +42,15 @@
 
 /* Define if you have the libmcrypt library installed */
 #undef HAVE_LIBMCRYPT
+
+/* Define to the unsigned 32 bit type. */
+#undef uint32_t
+
+/* Define to the signed 32 bit type. */
+#undef int32_t
+
+/* Define to the unsigned 16 bit type. */
+#undef uint16_t
+
+/* Define to the signed 16 bit type*/
+#undef int16_t
