@@ -13,7 +13,7 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 8
-#define DACT_VER_REVISION 2
+#define DACT_VER_REVISION 3
 #ifdef DEBUG
 #define DACT_VER_SUB	"dev"
 #else
@@ -76,16 +76,17 @@
 #include "getopt.h"
 #endif
 
-#ifdef HAVE_STDINT_H
-#include <stdint.h>
-#else
-#include "stdint.h"
-#endif
-
 #ifndef HAVE_STRSEP
 #include "strsep.h"
 #endif
 
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h>
+#endif
+
 #define DACT_MAGIC_NUMBER 0x444354C3
 #define DACT_MAGIC_OFFSET 0
 #define DACT_MAGIC_SIZE   4
