@@ -267,7 +267,13 @@ void strtolower(char *str) {
 	while (str[x]) { str[x]=tolower(str[x]); x++; }
 }
 
-char *mime64(char *str) {
+char *mime64(unsigned char *str) {
+	int x=strlen(str);
+	return(mimes64(str,&x));
+}
+
+
+char *mimes64(unsigned char *str, int *size) {
 	char *ret;
 	char mimeabet[64]="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 	int i=0, x=0, m, bit_buf_sze;
@@ -276,9 +282,9 @@ char *mime64(char *str) {
 	bit_buf_sze=bit_buffer_size(); /* Save the bit buffer, in case in use */
 	bit_buf_sto=bit_buffer_read(bit_buf_sze);
 
-	if ((ret=malloc((int) ((((float)strlen(str))*1.5)+6)))==NULL) return(NULL);
+	if ((ret=malloc((int) ((((float)(*size))*1.5)+6)))==NULL) return(NULL);
 
-	while (i<strlen(str)) {
+	while (i<(*size)) {
 		while (bit_buffer_size()>=6) ret[x++]=mimeabet[bit_buffer_read(6)];
 		if ((bit_buffer_size()+8)<=32) bit_buffer_write(str[i++],8);
 	}
@@ -288,6 +294,32 @@ char *mime64(char *str) {
 
 	bit_buffer_write(bit_buf_sto, bit_buf_sze); /* Restore it */
 
+	*size=x;
+
+	return(ret);
+}
+
+char *demime64(unsigned char *str) {
+	char *ret;
+	char mimeabet[64]="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+	int i=0, x=0, m, bit_buf_sze;
+	uint32_t bit_buf_sto;
+
+	bit_buf_sze=bit_buffer_size(); /* Save the bit buffer, in case in use */
+	bit_buf_sto=bit_buffer_read(bit_buf_sze);
+
+	if ((ret=malloc((int) ((((float)strlen(str))*0.75)+6)))==NULL) return(NULL);
+
+	while (i<strlen(str)) {
+		if (str[i]=='=') break;
+		while (bit_buffer_size()>=8) ret[x++]=bit_buffer_read(8);
+		if ((bit_buffer_size()+6)<=32) bit_buffer_write(strchr(mimeabet,str[i++])-mimeabet,6);
+	}
+	while (bit_buffer_size()>=8) ret[x++]=bit_buffer_read(8);
+	if ((m=bit_buffer_size())) ret[x++]=bit_buffer_read(m)<<(8-m);
+
+	bit_buffer_write(bit_buf_sto, bit_buf_sze); /* Restore it */
+
 	return(ret);
 }
 
