@@ -6,7 +6,9 @@ int parse_url(const char *url, char *scheme, char *username, char *password, cha
 void strtolower(char *str);
 char *parse_url_subst(const char *src, const char *fname);
 char *parse_url_subst_dist(void);
-char *mime64(char *str);
+char *mime64(unsigned char *str);
+char *mimes64(unsigned char *str, int *size);
+char *demime64(unsigned char *str);
 ssize_t read_f(int fd, void *buf, size_t count);
 uint32_t hash_fourbyte(unsigned char *str, const char term);
 #endif
